@@ -21,6 +21,7 @@ from tkinter import messagebox
 from tkinter import scrolledtext
 import matplotlib
 import pkg_resources
+import datetime
 
 try:
   matplotlib.use('TkAgg')
@@ -47,7 +48,8 @@ solarChoices = {
 
 loadChoices = {
   'default':{'t':[0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24],
-             'p':[0.677,0.6256,0.6087,0.5833,0.58028,0.6025,0.657,0.7477,0.832,0.88,0.94,0.989,0.985,0.98,0.9898,0.999,1,0.958,0.936,0.913,0.876,0.876,0.828,0.756,0.677]}
+             'p':[0.677,0.6256,0.6087,0.5833,0.58028,0.6025,0.657,0.7477,0.832,0.88,0.94,0.989,0.985,0.98,0.9898,0.999,1,0.958,0.936,0.913,0.876,0.876,0.828,0.756,0.677]},
+  'flat':{'t':[0,24],'p':[1.0, 1.0]}
   }
 
 inverterChoices = {
@@ -133,9 +135,9 @@ class DERConfigGUI:
     self.toolbar = NavigationToolbar2Tk(self.canvas_feeder, self.f1, pack_toolbar=False)
     self.toolbar.update()
     self.toolbar.grid(row=2, columnspan=2)
-    self.UpdateFeeder(None)
 
     self.f2 = ttk.Frame(self.nb, name='varsDER')
+    self.UpdateFeeder(None) # this updates f2 with DER information on the selected feeder
 
     self.f3 = ttk.Frame(self.nb, name='varsSolar')
     lab = ttk.Label(self.f3, text='Solar Profile: ', relief=tk.RIDGE)
@@ -164,8 +166,15 @@ class DERConfigGUI:
     self.cb_load.set(next(iter(loadChoices)))
     self.cb_load.grid(row=0, column=1, sticky=tk.NSEW)
     self.cb_load.bind('<<ComboboxSelected>>', self.UpdateLoadProfile)
+    lab = ttk.Label(self.f4, text='Load Multiplier: ', relief=tk.RIDGE)
+    lab.grid(row=0, column=2, sticky=tk.NSEW)
+    self.ent_load_mult = ttk.Entry(self.f4, name='load_mult')
+    self.ent_load_mult.insert(0, '1.0')
+    self.ent_load_mult.grid(row=0, column=3, sticky=tk.NSEW)
     self.f4.columnconfigure(0, weight=0)
-    self.f4.columnconfigure(1, weight=1)
+    self.f4.columnconfigure(1, weight=0)
+    self.f4.columnconfigure(2, weight=0)
+    self.f4.columnconfigure(3, weight=1)
     self.f4.rowconfigure(0, weight=0)
     self.f4.rowconfigure(1, weight=1)
     self.fig_load = plt.figure(figsize=(5, 4), dpi=100)
@@ -173,7 +182,7 @@ class DERConfigGUI:
     self.ax_load.set_xlabel('Time [hr]')
     self.ax_load.set_ylabel('Power [pu]')
     self.canvas_load = FigureCanvasTkAgg(self.fig_load, master=self.f4)
-    self.canvas_load.get_tk_widget().grid(row=1, columnspan=2, sticky=tk.W + tk.E + tk.N + tk.S)
+    self.canvas_load.get_tk_widget().grid(row=1, columnspan=4, sticky=tk.W + tk.E + tk.N + tk.S)
     self.canvas_load.draw()
     self.UpdateLoadProfile(None)
 
@@ -202,10 +211,12 @@ class DERConfigGUI:
     lab.grid(row=0, column=0, sticky=tk.NSEW)
     self.cb_soln_mode = ttk.Combobox(self.f6, values=solutionModeChoices, name='cbSolutionMode')
     self.cb_soln_mode.grid(row=0, column=1, sticky=tk.NSEW)
+    self.cb_soln_mode.set('DAILY')
     lab = ttk.Label(self.f6, text='Control Mode', relief=tk.RIDGE)
     lab.grid(row=0, column=2, sticky=tk.NSEW)
     self.cb_ctrl_mode = ttk.Combobox(self.f6, values=controlModeChoices, name='cbControlMode')
     self.cb_ctrl_mode.grid(row=0, column=3, sticky=tk.NSEW)
+    self.cb_ctrl_mode.set('STATIC')
     lab = ttk.Label(self.f6, text='Stop Time [min]:', relief=tk.RIDGE)
     lab.grid(row=1, column=0, sticky=tk.NSEW)
     self.ent_stop = ttk.Entry(self.f6, name='stop')
@@ -214,20 +225,26 @@ class DERConfigGUI:
     lab = ttk.Label(self.f6, text='Time Step [s]:', relief=tk.RIDGE)
     lab.grid(row=1, column=2, sticky=tk.NSEW)
     self.ent_step = ttk.Entry(self.f6, name='step')
-    self.ent_step.insert(0, '5')
+    self.ent_step.insert(0, '300')
     self.ent_step.grid(row=1, column=3, sticky=tk.NSEW)
     #ttk.Style().configure('TButton', background='blue')
+    self.output_details = tk.IntVar()
+    self.output_details.set(1)
+    self.cbk_detail = ttk.Checkbutton(self.f6, text='Output PV Details', variable=self.output_details)
+    self.cbk_detail.grid(row=2, column=0, sticky=tk.NSEW)
     ttk.Style().configure('TButton', foreground='blue')
     self.btn_run = ttk.Button(self.f6, text='Run', command=self.RunOpenDSS)
-    self.btn_run.grid(row=2, column=0, sticky=tk.NSEW)
+    self.btn_run.grid(row=2, column=1, sticky=tk.NSEW)
     self.txt_output = scrolledtext.ScrolledText(self.f6)
     self.txt_output.grid(row=3, columnspan=4, sticky=tk.W + tk.E + tk.N + tk.S)
     self.f6.rowconfigure (0, weight=0)
     self.f6.rowconfigure (1, weight=0)
     self.f6.rowconfigure (2, weight=0)
     self.f6.rowconfigure (3, weight=1)
-
-#    self.txt_output.insert ('end', 'Stuff')
+    self.f6.columnconfigure (0, weight=0)
+    self.f6.columnconfigure (1, weight=0)
+    self.f6.columnconfigure (2, weight=0)
+    self.f6.columnconfigure (3, weight=1)
 
     self.nb.add(self.f1, text='Network', underline=0, padding=2)
     self.nb.add(self.f2, text='DER', underline=0, padding=2)
@@ -243,91 +260,6 @@ class DERConfigGUI:
 #      self.master.quit()
 #      self.master.destroy()
 
-# def AttachFrame(self, tag, vars):
-#   """Creates a GUI page and loads it with data
-#
-#   Label, Combobox and Entry (i.e. edit) controls are automatically created for each row of data
-#
-#   Args:
-#     tag (str): the name of the Frame, i.e., GUI page
-#     vars (dict): the section of case configuration data to be loaded onto this new GUI page
-#   """
-#   f = ttk.Frame(self.nb, name=tag)
-#   lab = ttk.Label(f, text='Parameter', relief=tk.RIDGE)
-#   lab.grid(row=0, column=0, sticky=tk.NSEW)
-#   lab = ttk.Label(f, text='Value', relief=tk.RIDGE)
-#   lab.grid(row=0, column=1, sticky=tk.NSEW)
-#   lab = ttk.Label(f, text='Units/Notes', relief=tk.RIDGE)
-#   lab.grid(row=0, column=2, sticky=tk.NSEW)
-#   for i in range(len(vars)):
-#     lab = ttk.Label(f, text=vars[i][0], relief=tk.RIDGE)
-#     lab.grid(row=i + 1, column=0, sticky=tk.NSEW)
-#     varName = (vars[i][3] + '#' + vars[i][4]).lower()
-#     if len(vars[i]) > 5:
-#       cb = ttk.Combobox(f, values=globals()[vars[i][5]], name=varName)
-#       cb.set(vars[i][1])
-#       cb.grid(row=i + 1, column=1, sticky=tk.NSEW)
-#     else:
-#       ent = ttk.Entry(f, name=varName)
-#       ent.insert(0, vars[i][1])
-#       ent.grid(row=i + 1, column=1, sticky=tk.NSEW)
-#     lab = ttk.Label(f, text=vars[i][2], relief=tk.RIDGE)
-#     lab.grid(row=i + 1, column=2, sticky=tk.NSEW)
-#   f.columnconfigure(0, weight=1)
-#   f.columnconfigure(1, weight=2)
-#   f.columnconfigure(2, weight=1)
-#   return f
-#
-# def ReloadFrame(self, f, vars):
-#   """Helper function to recreate the GUI page controls and load them with values
-#
-#   Args:
-#     f (Frame): the GUI page to reload
-#     vars (dict): the section of case configuration with values to be loaded
-#   """
-#   for i in range(len(vars)):
-#     ent = f.grid_slaves(row=i + 1, column=1)[0]
-#     ent.delete(0, tk.END)
-#     ent.insert(0, vars[i][1])
-#
-# def mcSample(self, var):
-#   """Return an appropriate random value for each Monte Carlo variable choice
-#
-#   Args:
-#     var (str): one of ElectricCoolingParticipation, ThermostatRampMid, ThermostatOffsetLimitMid, WeekdayEveningStartMid or WeekdayEveningSetMid
-#   """
-#   if var == 'ElectricCoolingParticipation':
-#     return '{:.3f}'.format(np.random.uniform(0, 100))
-#   elif var == 'ThermostatRampMid':
-#     return '{:.3f}'.format(np.random.uniform(1.0, 4.0))
-#   elif var == 'ThermostatOffsetLimitMid':
-#     return '{:.3f}'.format(np.random.uniform(0, 6.0))
-#   elif var == 'WeekdayEveningStartMid':
-#     return '{:.3f}'.format(np.random.uniform(16.5, 18.0))
-#   elif var == 'WeekdayEveningSetMid':
-#     return '{:.3f}'.format(np.random.uniform(68.0, 74.0))
-#   else:
-#     return '{:.3f}'.format(np.random.uniform(0, 1))
-#
-# def mcBand(self, var):
-#   """Find the band size corresponding to each Monte Carlo variable choice
-#
-#   Args:
-#     var (str): one of ElectricCoolingParticipation, ThermostatRampMid, ThermostatOffsetLimitMid, WeekdayEveningStartMid or WeekdayEveningSetMid
-#   """
-#   if var == 'ElectricCoolingParticipation':
-#     return 10.0
-#   elif var == 'ThermostatRampMid':
-#     return 0.5
-#   elif var == 'ThermostatOffsetLimitMid':
-#     return 2.0
-#   elif var == 'WeekdayEveningStartMid':
-#     return 1.0
-#   elif var == 'WeekdayEveningSetMid':
-#     return 1.0
-#   else:
-#     return 0.0
-#
 # def SizeMonteCarlo(self, n):
 #   """Initializes the Monte Carlo data structures with variable choices and samples
 #
@@ -434,92 +366,139 @@ class DERConfigGUI:
 #     w1.grid(row=i + 2 + startRow, column=1, sticky=tk.NSEW)
 #     w2.grid(row=i + 2 + startRow, column=2, sticky=tk.NSEW)
 #     w3.grid(row=i + 2 + startRow, column=3, sticky=tk.NSEW)
-#
-# def ReadFrame(self, f, vars):
-#   """Helper function that reads values from gridded GUI controls into the local case configuration
-#
-#   Args:
-#     f (Frame): the GUI page to read
-#     vars (dict): the local data structure to update
-#   """
-#   for w in f.grid_slaves():
-#     col = int(w.grid_info()['column'])
-#     row = int(w.grid_info()['row'])
-#     if col == 1 and row > 0 and row <= len(vars):
-#       val = w.get()
-#       try:
-#         tmp = int(val)
-#         val = tmp
-#       except:
-#         try:
-#           tmp = float(val)
-#           val = tmp
-#         except:
-#           pass
-#       section = vars[row - 1][3]
-#       attribute = vars[row - 1][4]
-#       config[section][attribute] = val
 #
   def RunOpenDSS(self):
-#    dss = py_dss_interface.DSSDLL()
-#    print (pkg_resources.get_default_cache())
-#    fdr_path = pkg_resources.resource_filename (__name__, 'models/ieee_lvn')
-#    print (fdr_path)
-#    pkg_resources.resource_listdir (__name__, 'models/ieee_lvn')
-    dict = i2x.test_opendss_interface(choice = 'ieee9500', 
-                                      pvcurve = 'pcloud', 
-                                      loadmult = 0.5, 
-                                      stepsize = 300, 
-                                      numsteps = 288, 
+    load_mult = float(self.ent_load_mult.get())
+    feeder_choice = self.cb_feeder.get()
+    soln_mode = self.cb_soln_mode.get()
+    ctrl_mode = self.cb_ctrl_mode.get()
+    solar_profile = self.cb_solar.get()
+    load_profile = self.cb_load.get()
+    inv_mode = self.cb_inverter.get()
+    stop_minutes = int(self.ent_stop.get())
+    step_seconds = int(self.ent_step.get())
+    num_steps = int (60 * stop_minutes / step_seconds)
+    print (feeder_choice, solar_profile, load_mult, load_profile, inv_mode,
+           soln_mode, ctrl_mode, step_seconds, num_steps)
+    dict = i2x.test_opendss_interface(choice = feeder_choice,
+                                      pvcurve = solar_profile,
+                                      loadmult = load_mult,
+                                      loadcurve = load_profile,
+                                      invmode = inv_mode, 
+                                      stepsize = step_seconds, 
+                                      numsteps = num_steps,
+                                      ctrlmode = ctrl_mode,
+                                      solnmode = soln_mode, 
                                       doc_fp=None)
-#   'kWh_Net':kWh_Net,
-#   'kWh_Load':kWh_Load,
-#   'kWh_Loss':kWh_Loss,
-#   'kWh_Gen':kWh_Gen,
-#   'kWh_PV':kWh_PV,
-#   'kvarh_PV':kvarh_PV,
-#   'kWh_EEN':kWh_EEN,
-#   'kWh_UE':kWh_UE,
-#   'kWh_OverN':kWh_OverN,
-#   'kWh_OverE':kWh_OverE}
-#    self.txt_output.delete(0, tk.END)
+    self.txt_output.insert(tk.END, 'Analysis Run on {:s} at {:s}'.format(feeder_choice, datetime.datetime.now().strftime('%a %d-%b-%Y %H:%M:%S')))
     self.txt_output.insert(tk.END, 'Number of Capacitor Switchings = {:d}\n'.format(dict['num_cap_switches']))
     self.txt_output.insert(tk.END, 'Number of Tap Changes = {:d}\n'.format(dict['num_tap_changes']))
     self.txt_output.insert(tk.END, 'Number of Relay Trips = {:d}\n'.format(dict['num_relay_trips']))
     self.txt_output.insert(tk.END, '{:d} Nodes with Low Voltage, Lowest={:.4f}pu at {:s}\n'.format(dict['num_low_voltage'], dict['vminpu'], dict['node_vmin']))
     self.txt_output.insert(tk.END, '{:d} Nodes with High Voltage, Highest={:.4f}pu at {:s}\n'.format(dict['num_high_voltage'], dict['vmaxpu'], dict['node_vmax']))
-    self.txt_output.insert(tk.END, 'Substation Energy =         {:9.2f} kWh\n'.format(dict['kWh_Net']))
-    self.txt_output.insert(tk.END, 'Load Served =               {:9.2f} kWh\n'.format(dict['kWh_Load']))
-    self.txt_output.insert(tk.END, 'Losses =                    {:9.2f} kWh\n'.format(dict['kWh_Loss']))
-    self.txt_output.insert(tk.END, 'Generation =                {:9.2f} kWh\n'.format(dict['kWh_Gen']))
-    self.txt_output.insert(tk.END, 'Solar Output =              {:9.2f} kWh\n'.format(dict['kWh_PV']))
-    self.txt_output.insert(tk.END, 'Solar Reactive Power =      {:9.2f} kWh\n'.format(dict['kvarh_PV']))
-    self.txt_output.insert(tk.END, 'Energy Exceeding Normal =   {:9.2f} kWh\n'.format(dict['kWh_EEN']))
-    self.txt_output.insert(tk.END, 'Unserved Energy =           {:9.2f} kWh\n'.format(dict['kWh_UE']))
-    self.txt_output.insert(tk.END, 'Normal Overload Energy =    {:9.2f} kWh\n'.format(dict['kWh_OverN']))
-    self.txt_output.insert(tk.END, 'Emergency Overload Energy = {:9.2f} kWh\n'.format(dict['kWh_OverE']))
+    self.txt_output.insert(tk.END, 'Substation Energy =         {:11.2f} kWh\n'.format(dict['kWh_Net']))
+    self.txt_output.insert(tk.END, 'Load Served =               {:11.2f} kWh\n'.format(dict['kWh_Load']))
+    self.txt_output.insert(tk.END, 'Losses =                    {:11.2f} kWh\n'.format(dict['kWh_Loss']))
+    self.txt_output.insert(tk.END, 'Generation =                {:11.2f} kWh\n'.format(dict['kWh_Gen']))
+    self.txt_output.insert(tk.END, 'Solar Output =              {:11.2f} kWh\n'.format(dict['kWh_PV']))
+    self.txt_output.insert(tk.END, 'Solar Reactive Power =      {:11.2f} kWh\n'.format(dict['kvarh_PV']))
+    self.txt_output.insert(tk.END, 'Energy Exceeding Normal =   {:11.2f} kWh\n'.format(dict['kWh_EEN']))
+    self.txt_output.insert(tk.END, 'Unserved Energy =           {:11.2f} kWh\n'.format(dict['kWh_UE']))
+    self.txt_output.insert(tk.END, 'Normal Overload Energy =    {:11.2f} kWh\n'.format(dict['kWh_OverN']))
+    self.txt_output.insert(tk.END, 'Emergency Overload Energy = {:11.2f} kWh\n'.format(dict['kWh_OverE']))
 
-    self.txt_output.insert(tk.END, 'PV Name                    kWh     kvarh     Vmin     Vmax    Vmean    Vdiff\n')
-    for key, row in dict['pvdict'].items():
-      self.txt_output.insert(tk.END, '{:20s} {:9.2f} {:9.2f} {:8.2f} {:8.2f} {:8.2f} {:8.2f}\n'.format(key, row['kWh'], row['kvarh'], 
+    if self.output_details.get() > 0:
+      self.txt_output.insert(tk.END, 'PV Name                    kWh     kvarh     Vmin     Vmax    Vmean    Vdiff\n')
+      for key, row in dict['pvdict'].items():
+        self.txt_output.insert(tk.END, '{:20s} {:9.2f} {:9.2f} {:8.2f} {:8.2f} {:8.2f} {:8.2f}\n'.format(key, row['kWh'], row['kvarh'], 
                                                                                row['vmin'], row['vmax'], row['vmean'], row['vdiff']))
 
 
+  def ResetDERPage(self):
+    for w in self.f2.grid_slaves():
+      w.grid_forget()
+
+    pvkw = 0.0
+    pvkva = 0.0
+    npv = len(self.pvder)
+    for key, row in self.pvder.items():
+      pvkw += row['kw']
+      pvkva += row['kva']
+
+    genkw = 0.0
+    genkva = 0.0
+    ngen = len(self.gender)
+    for key, row in self.gender.items():
+      genkw += row['kw']
+      genkva += row['kva']
+
+    batkw = 0.0
+    batkva = 0.0
+    nbat = len(self.batder)
+    for key, row in self.batder.items():
+      batkw += row['kw']
+      batkva += row['kva']
+
+    lab_load = ttk.Label(self.f2, text='Total Load = {:.2f} kW'.format(self.loadkw), relief=tk.RIDGE)
+    lab_load.grid(row=0, column=0, sticky=tk.NSEW)
+    lab_pv = ttk.Label(self.f2, text='Existing Solar = {:.2f} kVA, {:.2f} kW in {:d} units'.format(pvkva, pvkw, npv), relief=tk.RIDGE)
+    lab_pv.grid(row=1, column=0, sticky=tk.NSEW)
+    lab_bat = ttk.Label(self.f2, text='Existing Storage = {:.2f} kVA, {:.2f} kW in {:d} units'.format(batkva, batkw, nbat), relief=tk.RIDGE)
+    lab_bat.grid(row=2, column=0, sticky=tk.NSEW)
+    lab_gen = ttk.Label(self.f2, text='Existing Generation = {:.2f} kVA, {:.2f} kW in {:d} units'.format(genkva, genkw, ngen), relief=tk.RIDGE)
+    lab_gen.grid(row=3, column=0, sticky=tk.NSEW)
+    lab_roofs = ttk.Label(self.f2, text='{:d} Available Residential Rooftops, Use[%]:'.format(len(self.resloads)), relief=tk.RIDGE)
+    lab_roofs.grid(row=4, column=0, sticky=tk.NSEW)
+    self.ent_pct_roofs = ttk.Entry(self.f2, name='pct_roofs')
+    self.ent_pct_roofs.insert(0, '10.0')
+    self.ent_pct_roofs.grid(row=4, column=1, sticky=tk.NSEW)
+
+    lab = ttk.Label(self.f2, text='DER >= 100.0 kVA')
+    lab.grid(row=5, column=0, sticky=tk.NSEW)
+    lab = ttk.Label(self.f2, text='kW')
+    lab.grid(row=5, column=1, sticky=tk.NSEW)
+    lab = ttk.Label(self.f2, text='kVA')
+    lab.grid(row=5, column=2, sticky=tk.NSEW)
+    lab = ttk.Label(self.f2, text='Type')
+    lab.grid(row=5, column=3, sticky=tk.NSEW)
+
+    idx = 6
+    for key, row in self.largeder.items():
+      lab = ttk.Label(self.f2, text='Name={:s} Bus={:s} kV={:.2f} kW={:.2f} kVA={:.2f} Type={:s}'.format (key,
+                                                                                                          row['bus'],
+                                                                                                          row['kv'],
+                                                                                                          row['kw'],
+                                                                                                          row['kva'],
+                                                                                                          row['type']), 
+                      relief=tk.RIDGE)
+      lab.grid(row=idx, column=0, sticky=tk.NSEW)
+      e1 = ttk.Entry(self.f2, name='kw_{:s}'.format(key))
+      e1.insert(0, str(row['kw']))
+      e1.grid(row=idx, column=1, sticky=tk.NSEW)
+      e2 = ttk.Entry(self.f2, name='kva_{:s}'.format(key))
+      e2.insert(0, str(row['kva']))
+      e2.grid(row=idx, column=2, sticky=tk.NSEW)
+      cb1 = ttk.Combobox(self.f2, values=['solar','storage','generator'], name='type_{:s}'.format(key))
+      cb1.set(row['type'])
+      cb1.grid(row=idx, column=3, sticky=tk.NSEW)
+      idx += 1
+
   def UpdateFeeder(self, event):
     key = self.cb_feeder.get()
     row = feederChoices[key]
     self.feeder_name = key
     self.feeder_path = row['path']
     self.feeder_base = row['base']
-#    fname = os.path.join (self.feeder_path, row['network'])
     fname = pkg_resources.resource_filename (__name__, row['path'] + row['network'])
     self.G = i2x.load_opendss_graph(fname)
 
-    self.ax_feeder.cla()
-    i2x.plot_opendss_feeder (self.G, on_canvas=True, ax=self.ax_feeder, fig=self.fig_feeder)
-    self.canvas_feeder.draw()
+    self.pvder, self.gender, self.batder, self.largeder, self.resloads, self.loadkw = i2x.parse_opendss_graph(self.G)
 
-#    messagebox.showinfo(title='Combobox', message='Feeder File=' + fname)
+    self.ax_feeder.cla()
+    i2x.plot_opendss_feeder (self.G, plot_labels=True, on_canvas=True, 
+                             ax=self.ax_feeder, fig=self.fig_feeder)
+    self.canvas_feeder.draw()
+    self.ResetDERPage()
 
   def UpdateSolarProfile(self, event):
     key = self.cb_solar.get()
@@ -536,9 +515,6 @@ class DERConfigGUI:
     self.ax_solar.grid()
     self.canvas_solar.draw()
 
-#    msg = 'Solar={:s} dt={:.1f}s tmax={:.1f}s npts={:d}'.format(key, dt, tmax, npts)
-#    messagebox.showinfo(title='Combobox', message=msg)
-
   def UpdateLoadProfile(self, event):
     ticks = [0, 4, 8, 12, 16, 20, 24]
     key = self.cb_load.get()
@@ -571,81 +547,7 @@ class DERConfigGUI:
 #   ctl.delete(0, tk.END)
 #   ctl.insert(0, val)
 #
-# def ReadLatLong(self):
-#   """Updates the Latitude and Longitude from TMY3 file
-#   """
-#   weatherpath = self.path_ent.get()
-#   weatherfile = self.tmy3_ent.get()
-#   fname = weather_path + weatherfile
-#   if os.path.isfile(fname):
-#     fd = open(fname, 'r')
-#     rd = csv.reader(fd, delimiter=',', skipinitialspace=True)
-#     row = next(rd)
-#     tmy3source = row[0]
-#     tmy3station = row[1]
-#     tmy3state = row[2]
-#     tmy3tzoffset = float(row[3])
-#     tmy3latitude = float(row[4])
-#     tmy3longitude = float(row[5])
-#     tmy3altitude = float(row[6])
-#     self.update_entry(self.tz_ent, tmy3tzoffset)
-#     self.update_entry(self.lat_ent, tmy3latitude)
-#     self.update_entry(self.long_ent, tmy3longitude)
-#     self.update_entry(self.alt_ent, tmy3altitude)
-#     fd.close()
-#   else:
-#     print(fname, 'not found')
-#
 # def SaveConfig(self):
-#   """Updates the local case configuration from the GUI, queries user for a file name, and then saves case configuration to that file
-#   """
-#   self.ReadFrame(self.f1, varsTM)
-#   self.ReadFrame(self.f2, varsFD)
-#   self.ReadFrame(self.f3, varsPP)
-#   self.ReadFrame(self.f4, varsEP)
-#   self.ReadFrame(self.f5, varsAC)
-#   self.ReadFrame(self.f6, varsTS)
-#
-#   col1 = self.f7.children['cb1'].get()
-#   col2 = self.f7.children['cb2'].get()
-#   col3 = self.f7.children['cb3'].get()
-#   config['MonteCarloCase']['Variable1'] = col1
-#   config['MonteCarloCase']['Variable2'] = col2
-#   config['MonteCarloCase']['Variable3'] = col3
-#   use1 = col1 != 'None'
-#   use2 = col2 != 'None'
-#   use3 = col3 != 'None'
-#   band1 = 'Mid' in col1
-#   band2 = 'Mid' in col2
-#   band3 = 'Mid' in col3
-#   numCases = int(
-#     self.f7.children['rows'].get())  # what if user changed entry and didn't click Update...global numCases?
-#   for w in self.f7.grid_slaves():
-#     row = int(w.grid_info()['row'])
-#     col = int(w.grid_info()['column'])
-#     if row == 3:
-#       if col == 1 and band1:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Band1'] = val
-#       if col == 2 and band2:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Band2'] = val
-#       if col == 3 and band3:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Band3'] = val
-#     elif row > 4:
-#       if col == 1 and use1:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Samples1'][row - 5] = val
-#       if col == 2 and use2:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Samples2'][row - 5] = val
-#       if col == 3 and use3:
-#         val = float(w.get())
-#         config['MonteCarloCase']['Samples3'][row - 5] = val
-#   if not os.path.exists(tesp_share):
-#     if not messagebox.askyesno('Continue to Save?', 'TESP Support Directory: ' + tesp_share + ' not found.'):
-#       return
 #   fname = filedialog.asksaveasfilename(initialdir='~/src/examples/te30',
 #                      title='Save JSON Configuration to',
 #                      defaultextension='json')
@@ -654,22 +556,7 @@ class DERConfigGUI:
 #     json.dump(config, op, ensure_ascii=False, indent=2)
 #     op.close()
 #
-# def JsonToSection(self, jsn, vars):
-#   """Helper function that transfers a JSON file segment into GUI data structures
-#
-#   Args:
-#     jsn (dict): the loaded JSON file
-#     vars (dict): the local data structure
-#   """
-#   for i in range(len(vars)):
-#     section = vars[i][3]
-#     attribute = vars[i][4]
-#     vars[i][1] = jsn[section][attribute]
-#     config[section][attribute] = jsn[section][attribute]
-#
 # def OpenConfig(self):
-#   """Opens a JSON case configuration; transfers its data to the GUI
-#   """
 #   fname = filedialog.askopenfilename(initialdir='~/src/examples/te30',
 #                      title='Open JSON Configuration',
 #                      filetypes=(("JSON files", "*.json"), ("all files", "*.*")),
@@ -677,61 +564,7 @@ class DERConfigGUI:
 #   lp = open(fname)
 #   cfg = json.loads(lp.read())
 #   lp.close()
-#   self.JsonToSection(cfg, varsTM)
-#   self.JsonToSection(cfg, varsFD)
-#   self.JsonToSection(cfg, varsPP)
-#   self.JsonToSection(cfg, varsEP)
-#   self.JsonToSection(cfg, varsAC)
-#   self.JsonToSection(cfg, varsTS)
-#   self.ReloadFrame(self.f1, varsTM)
-#   self.ReloadFrame(self.f2, varsFD)
-#   self.ReloadFrame(self.f3, varsPP)
-#   self.ReloadFrame(self.f4, varsEP)
-#   self.ReloadFrame(self.f5, varsAC)
-#   self.ReloadFrame(self.f6, varsTS)
 #
-#   numCases = int(cfg['MonteCarloCase']['NumCases'])
-#   config['MonteCarloCase']['NumCases'] = numCases
-#   ent = self.f7.children['rows']
-#   ent.delete(0, tk.END)
-#   ent.insert(0, str(numCases))
-#
-#   var1 = cfg['MonteCarloCase']['Variable1']
-#   config['MonteCarloCase']['Variable1'] = var1
-#   self.f7.children['cb1'].set(var1)
-#
-#   var2 = cfg['MonteCarloCase']['Variable2']
-#   config['MonteCarloCase']['Variable2'] = var2
-#   self.f7.children['cb2'].set(var2)
-#
-#   var3 = cfg['MonteCarloCase']['Variable3']
-#   config['MonteCarloCase']['Variable3'] = var3
-#   self.f7.children['cb3'].set(var3)
-#
-#   config['MonteCarloCase']['Band1'] = cfg['MonteCarloCase']['Band1']
-#   config['MonteCarloCase']['Band2'] = cfg['MonteCarloCase']['Band2']
-#   config['MonteCarloCase']['Band3'] = cfg['MonteCarloCase']['Band3']
-#
-#   config['MonteCarloCase']['Samples1'] = [0] * numCases
-#   config['MonteCarloCase']['Samples2'] = [0] * numCases
-#   config['MonteCarloCase']['Samples3'] = [0] * numCases
-#
-#   for i in range(numCases):
-#     config['MonteCarloCase']['Samples1'][i] = cfg['MonteCarloCase']['Samples1'][i]
-#     config['MonteCarloCase']['Samples2'][i] = cfg['MonteCarloCase']['Samples2'][i]
-#     config['MonteCarloCase']['Samples3'][i] = cfg['MonteCarloCase']['Samples3'][i]
-#
-#   self.SizeMonteCarloFrame(self.f7)
-#
-# def UpdateMonteCarloFrame(self):
-#   """Transfer data from the Monte Carlo page into the case configuration
-#   """
-#   numCases = int(self.f7.children['rows'].get())
-#   config['MonteCarloCase']['Variable1'] = self.f7.children['cb1'].get()
-#   config['MonteCarloCase']['Variable2'] = self.f7.children['cb2'].get()
-#   config['MonteCarloCase']['Variable3'] = self.f7.children['cb3'].get()
-#   self.SizeMonteCarlo(numCases)
-#   self.SizeMonteCarloFrame(self.f7)
 
 def show_der_config():
   """Runs the GUI. Reads and writes JSON case configuration files.
@@ -746,6 +579,5 @@ def show_der_config():
     except UnicodeDecodeError:
       pass
 
-
 if __name__ == "__main__":
   show_der_config()
